/* BdfServer_Commands - Copyright (c) 2015-2023 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.addenda;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.EditSession;
import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import fr.exemole.bdfserver.tools.instruction.BdfErrors;
import net.fichotheque.addenda.Addenda;
import net.fichotheque.addenda.Document;
import net.fichotheque.tools.FichothequeTools;
import net.mapeadores.util.logging.ErrorMessageException;
import net.mapeadores.util.request.RequestMap;


/**
 *
 * @author Vincent Calame
 */
public class DocumentRemoveCommand extends AbstractBdfCommand {

    public final static String COMMANDNAME = "DocumentRemove";
    public final static String COMMANDKEY = "_ ADD-06";
    private Document document;

    public DocumentRemoveCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return true;
    }

    @Override
    protected void doCommand() throws ErrorMessageException {
        Addenda addenda = document.getAddenda();
        try (EditSession session = startEditSession(Domains.ADDENDA, COMMANDNAME)) {
            FichothequeTools.remove(session.getFichothequeEditor(), document);
        }
        putResultObject(ADDENDA_OBJ, addenda);
        setDone("_ done.addenda.documentremove");
    }

    @Override
    protected void checkParameters() throws ErrorMessageException {
        document = getMandatoryDocument();
        getPermissionChecker()
                .checkWrite(document);
        if (!checkConfirmation()) {
            throw BdfErrors.error("_ error.empty.confirmationcheck_remove");
        }
    }

}
